# HappyRandomBirthday
Don't know how to say Happy birthday to a friend ? Tired of saying the same thing every single year? No more!  With this module you will always know how to cheer up your friend for their special day.


To install follow the instructions from https://pypi.org/project/HappyRandomBirthday/
and to use it you must import in your favorite python shell as:


import HappyRandomBirthday


Enjoy! and Happy Birthday to your loved ones. 
